@@ -1,10 +1,10 @@
 <?php
 if (!isset($gCms)) exit;
-if (! $this->CheckPermission('Modify Any Page')) {
+if (! $this->CheckPermission('Modify Templates')) {
   return $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
 }
 
-$db = &$gCms->GetDb();
+$db = $gCms->GetDb();
 
 if (isset($params['submit']))
 	{
