@@ -5,10 +5,11 @@ $taboptarray = array( 'mysql' => 'TYPE=MyISAM' );
 $dict = NewDataDictionary( $db );
 $flds = "
          tree_id I KEY,
-		 alias C(80),
-	 	 description C(255),
-	     max_depth I,
-		 template X
+	 alias C(80),
+	 description C(255),
+	 max_depth I,
+	 template X,
+         allow_decision_wysiwyg I1
 ";
 $sqlarray = $dict->CreateTableSQL( cms_db_prefix()."module_dectree_trees",
 				   $flds, 
@@ -26,7 +27,7 @@ $flds = "
 	     alternate X,
 	     prompt C(255),
 	     suggestion X,
-		 order_by I
+ 	     order_by I
 ";
 $sqlarray = $dict->CreateTableSQL( cms_db_prefix()."module_dectree_decs",
 				   $flds, 
